"use client";

import Image from "next/image";
import eye_off from "./icons/eye-off.svg";
import eye_on from "./icons/eye-on.svg";
import alert from "./icons/alert-circle.svg";
import { useState } from "react";

interface IAuthInputProps extends React.InputHTMLAttributes<HTMLInputElement> {
  isPassword?: boolean;
  label: string;
  error?: string;
}

const AuthInput: React.FC<IAuthInputProps> = ({
  isPassword,
  label,
  error,
  placeholder,
  name,
  type,
}: IAuthInputProps) => {
  const [isOpen, setIsOpen] = useState<boolean>(false);
  return (
    <div className="flex flex-col gap-[6px]">
      <label className="text-[14px] leading-5 text-gray-700">{label}</label>
      <div
        className={`px-[10px] py-[14px] flex items-center border border-gray-300 rounded-lg shadow-sm bg-white${
          error ? "-with-error" : "border border-red-400"
        }`}
      >
        <input
          name={name}
          placeholder={placeholder}
          className="w-full text-[16px] leading-6 text-gray-900"
          type={!isPassword ? type : isOpen ? type : "password"}
        />
        {isPassword && (
          <button onClick={() => setIsOpen((prev) => !prev)} type="button">
            <Image src={isOpen ? eye_on : eye_off} alt="Eye Icon" />
          </button>
        )}
      </div>
      {error && (
        <p className="flex items-center justify-between text-[14px] font-normal leading-5 text-red-500">
          {error} <Image src={alert} alt="Alert Icon" />
        </p>
      )}
    </div>
  );
};

export default AuthInput;
