"use client";
import React, { FC, useState } from "react";
import { z } from "zod";
import { zodResolver } from "@hookform/resolvers/zod";
import AuthInput from "@/features/AuthInput";
import Loader from "@/shared/ui/Loader/Loader";
import Link from "next/link";
import { useForm } from "react-hook-form";

// interface SignInProps {
//   isLoading: boolean;
//   onSubmitFunc: () => void;
//   noAccountError: Error | null;
// }
const SignInForm = ({}) => {
  const signInFormScheme = z.object({
    email: z.string().email("Неверный формат email"),
    password: z.string().min(8, "Пароль должен содержать минимум 8 символов"),
  });

  type FormFields = z.infer<typeof signInFormScheme>;

  const {
    register,
    handleSubmit,
    formState: { errors },
  } = useForm<FormFields>({
    resolver: zodResolver(signInFormScheme),
  });

  const onSubmit = (data: FormFields) => {};
  return (
    <form className="mb-2 w-[360px] flex flex-col">
      <div className="flex flex-col gap-5">
        <AuthInput
          type="email"
          label="Email"
          placeholder="Введите email"
          error={errors.email?.message}
          {...register("email", { required: true })}
        />
        <AuthInput
          isPassword
          label="Пароль"
          placeholder="Введите пароль"
          error={errors.password?.message}
          {...register("password", { required: true })}
        />
        {errors.root && (
          <div className="text-red-500">{errors.root.message}</div>
        )}
        <button
          type="submit"
          className="p-4 h-[50px] w-full font-bold leading-6 text-white bg-light-blue rounded-md"
          // disabled={isLoading}
        >
          {/* {isLoading ? <Loader /> : "Войти"} */}
          Войти
        </button>
        <div className="text-blue font-semibold pt-2 cursor-pointer">
          <Link
            href="/forgot-password-email"
            className="text-blue font-semibold pt-2 cursor-pointer "
          >
            Забыли пароль?
          </Link>
        </div>
      </div>
    </form>
  );
};

export default SignInForm;
